@@ -1,5 +1,8 @@
+"""Module provider for a localzone"""
 from __future__ import absolute_import, print_function
 import logging
+import types
+from time import localtime, strftime, time
 
 from .base import Provider as BaseProvider
 
@@ -17,12 +20,31 @@ LOGGER = logging.getLogger(__name__)
 NAMESERVER_DOMAINS = []
 
 
-def ProviderParser(subparser):
+# Monkeypatch localzone.models.Zone._increment_serial to make it compatible with dnspython 2.x
+def _increment_serial(self):
+    next_serial = int(strftime("%Y%m%d00", localtime(time())))
+
+    if next_serial <= self.soa.rdata.serial:
+        next_serial = self.soa.rdata.serial + 1
+
+    if hasattr(self.soa.rdata, 'replace'):
+        self.soa._data = self.soa._data._replace(rdata=self.soa.rdata.replace(serial=next_serial))  # pylint: disable=protected-access
+    else:
+        self.soa.rdata.serial = next_serial
+
+
+def _patch_zone(zone):
+    zone._increment_serial = types.MethodType(_increment_serial, zone)  # pylint: disable=protected-access
+
+
+def provider_parser(subparser):
+    """Configure provider parserfor a localzone"""
     subparser.add_argument(
         "--filename", help="specify location of zone master file")
 
 
 class Provider(BaseProvider):
+    """Provider class for a localzone"""
     def __init__(self, config):
         super(Provider, self).__init__(config)
         self.ttl = self._get_lexicon_option("ttl")
@@ -30,11 +52,11 @@ class Provider(BaseProvider):
         self.origin = self.domain + "."
         self.filename = self._get_provider_option("filename")
 
-    def authenticate(self):
-        """Authentication is not required for localzone."""
+    def _authenticate(self):
+        # Authentication is not required for localzone.
         pass
 
-    def create_record(self, type, name, content):
+    def _create_record(self, rtype, name, content):
         """
         Create a resource record. If a record already exists with the same
         content, do nothing.
@@ -47,14 +69,16 @@ class Provider(BaseProvider):
         if self.ttl:
             ttl = self.ttl
 
-        with localzone.manage(self.filename, self.origin, autosave=True) as z:
-            if z.add_record(name, type, content, ttl=ttl):  # pylint: disable=no-member
+        with localzone.manage(self.filename, self.origin, autosave=True) as zone:
+            # TODO: Remove this monkeypatch once upstream Class is fixed.
+            _patch_zone(zone)
+            if zone.add_record(name, rtype, content, ttl=ttl):  # pylint: disable=no-member
                 result = True
 
         LOGGER.debug("create_record: %s", result)
         return result
 
-    def list_records(self, type=None, name=None, content=None):
+    def _list_records(self, rtype=None, name=None, content=None):
         """
         Return a list of records matching the supplied params. If no params are
         provided, then return all zone records. If no records are found, return
@@ -62,13 +86,15 @@ class Provider(BaseProvider):
         """
         if name:
             name = self._relative_name(name)
-        if not type:
-            type = "ANY"
+        if not rtype:
+            rtype = "ANY"
 
-        filter = {"rdtype": type, "name": name, "content": content}
+        filter_query = {"rdtype": rtype, "name": name, "content": content}
 
-        with localzone.manage(self.filename, self.origin, autosave=True) as z:
-            records = z.find_record(**filter)  # pylint: disable=no-member
+        with localzone.manage(self.filename, self.origin, autosave=True) as zone:
+            # TODO: Remove this monkeypatch once upstream Class is fixed.
+            _patch_zone(zone)
+            records = zone.find_record(**filter_query)  # pylint: disable=no-member
 
         result = []
         for record in records:
@@ -88,7 +114,7 @@ class Provider(BaseProvider):
         LOGGER.debug("list_records: %s", result)
         return result
 
-    def update_record(self, identifier, type=None, name=None, content=None):
+    def _update_record(self, identifier, rtype=None, name=None, content=None):
         """
         Update a record. Returns `False` if no matching record is found.
         """
@@ -97,20 +123,22 @@ class Provider(BaseProvider):
         # TODO: some providers allow content-based updates without supplying an
         # ID, and therefore `identifier` is here optional. If we don't receive
         # an ID, look it up.
-        if not identifier and type and name:
-            records = self.list_records(type, name)
+        if not identifier and rtype and name:
+            records = self._list_records(rtype, name)
             if len(records) == 1:
                 identifier = records[0]["id"]
 
         if identifier and content:
-            with localzone.manage(self.filename, self.origin, autosave=True) as z:
-                if z.update_record(identifier, content):  # pylint: disable=no-member
+            with localzone.manage(self.filename, self.origin, autosave=True) as zone:
+                # TODO: Remove this monkeypatch once upstream Class is fixed.
+                _patch_zone(zone)
+                if zone.update_record(identifier, content):  # pylint: disable=no-member
                     result = True
 
         LOGGER.debug("update_record: %s", result)
         return result
 
-    def delete_record(self, identifier=None, type=None, name=None, content=None):
+    def _delete_record(self, identifier=None, rtype=None, name=None, content=None):
         """
         Delete record(s) matching the provided params. If there is no match, do
         nothing.
@@ -119,22 +147,22 @@ class Provider(BaseProvider):
 
         if identifier:
             ids.append(identifier)
-        elif not identifier and type and name:
-            records = self.list_records(type, name, content)
-            if len(records) > 0:
+        elif not identifier and rtype and name:
+            records = self._list_records(rtype, name, content)
+            if records:
                 ids = [record["id"] for record in records]
 
-        if len(ids) > 0:
+        if ids:
             LOGGER.debug("delete_records: %s", ids)
-            with localzone.manage(self.filename, self.origin, autosave=True) as z:
+            with localzone.manage(self.filename, self.origin, autosave=True) as zone:
+                # TODO: Remove this monkeypatch once upstream Class is fixed.
+                _patch_zone(zone)
                 for hashid in ids:
-                    z.remove_record(hashid)  # pylint: disable=no-member
+                    zone.remove_record(hashid)  # pylint: disable=no-member
                     LOGGER.debug("delete_record: %s", hashid)
 
         return True
 
-    def _request(self, **kwargs):
-        """
-        Not required.
-        """
+    def _request(self, action='GET', url='/', data=None, query_params=None):
+        # Not required
         pass
