@@ -1,13 +1,13 @@
 """Integration tests for Cloudflare"""
 from unittest import TestCase
 
-from lexicon.tests.providers.integration_tests import IntegrationTests
+from lexicon.tests.providers.integration_tests import IntegrationTestsV2
 
 
 # Hook into testing framework by inheriting unittest.TestCase and reuse
 # the tests which *each and every* implementation of the interface must
 # pass, by inheritance from define_tests.TheTests
-class CloudflareProviderTests(TestCase, IntegrationTests):
+class CloudflareProviderTests(TestCase, IntegrationTestsV2):
     """TestCase for Cloudflare"""
     provider_name = 'cloudflare'
     domain = 'pacalis.net'
