@@ -2,7 +2,7 @@
 from unittest import TestCase
 
 import pytest
-from lexicon.tests.providers.integration_tests import IntegrationTests
+from lexicon.tests.providers.integration_tests import IntegrationTestsV2
 
 
 # Hook into testing framework by inheriting unittest.TestCase and reuse
@@ -10,7 +10,7 @@ from lexicon.tests.providers.integration_tests import IntegrationTests
 # pass, by inheritance from define_tests.TheTests
 
 
-class CloudXNSProviderTests(TestCase, IntegrationTests):
+class CloudXNSProviderTests(TestCase, IntegrationTestsV2):
     """TestCase for CloudXNS"""
     provider_name = 'cloudxns'
     domain = 'capsulecd.com'
@@ -18,7 +18,7 @@ class CloudXNSProviderTests(TestCase, IntegrationTests):
     def _filter_post_data_parameters(self):
         return ['login_token']
 
-    # TODO: the following skipped suite and fixtures should be enabled
+    # TODO: enable the skipped tests
     @pytest.mark.skip(reason="new test, missing recording")
     def test_provider_when_calling_update_record_should_modify_record_name_specified(self):
         return
