@@ -18,16 +18,14 @@ parameters must be provided:
 """
 from unittest import TestCase
 
-from lexicon.tests.providers.integration_tests import IntegrationTests
-from lexicon.providers.nfsn import Provider
+from lexicon.tests.providers.integration_tests import IntegrationTestsV2
 
 
 # Hook into testing framework by inheriting unittest.TestCase and reuse
 # the tests which *each and every* implementation of the interface must
 # pass, by inheritance from integration_tests.IntegrationTests
-class NFSNProviderTests(TestCase, IntegrationTests):
+class NFSNProviderTests(TestCase, IntegrationTestsV2):
     """TestCase for NFSN"""
-    Provider = Provider
     provider_name = 'nfsn'
     domain = 'koupia.xyz'
 
