@@ -1,13 +1,11 @@
 """Integration tests for Onapp"""
 from unittest import TestCase
 
-from lexicon.tests.providers.integration_tests import IntegrationTests
-from lexicon.providers.onapp import Provider
+from lexicon.tests.providers.integration_tests import IntegrationTestsV2
 
 
-class OnappProviderTests(TestCase, IntegrationTests):
+class OnappProviderTests(TestCase, IntegrationTestsV2):
     """TestCase for Oneapp"""
-    Provider = Provider
     provider_name = 'onapp'
     domain = 'my-test.org'
 
