@@ -2,16 +2,14 @@
 from unittest import TestCase
 
 import pytest
-from lexicon.tests.providers.integration_tests import IntegrationTests
-from lexicon.providers.yandex import Provider
+from lexicon.tests.providers.integration_tests import IntegrationTestsV2
 
 
 # Hook into testing framework by inheriting unittest.TestCase and reuse
 # the tests which *each and every* implementation of the interface must
 # pass, by inheritance from define_tests.TheTests
-class YandexPDDProviderTests(TestCase, IntegrationTests):
+class YandexPDDProviderTests(TestCase, IntegrationTestsV2):
     """TestCase for Yandex"""
-    Provider = Provider
     provider_name = 'yandex'
     domain = 'capsulecd.com'
 
@@ -19,7 +17,7 @@ class YandexPDDProviderTests(TestCase, IntegrationTests):
         """Sensitive headers to be filtered."""
         return ['Authorization', 'PddToken']
 
-    # TODO: the following skipped suite and fixtures should be enabled
+    # TODO: enable the skipped tests
     @pytest.mark.skip(reason="new test, missing recording")
     def test_provider_when_calling_update_record_should_modify_record_name_specified(self):
         return
